#=====================================================================================================#
# -*- coding:Utf-8 -*-
# PlayMethode by DoCky (16/12/2007)
# Remerciemmment spéciale a NICOLOUS
# MATTIE'S EVENTSCRIPTS 2.0, PYTHON OPERATIONNEL




#  PUBLIC CLASS : PlayMethode.py  #

import es, random

class PlayMethode:
    """
        Classe public. Sélectionne une piste dans une liste selon une méthode a définir
        Pour utiliser cette classe, copier/coller dans un fichier python dans votre script
        Puis importer le module comme ceci: 'from PlayMethode import PlayMethode'


        Syntax (exemples):
            *listeDeSons = ["gungame/fichier son1.mp3", "myTeam/fichier son2.wav" , "ect"]

            *listeUserId =  - id unique d'un joueur
                            - liste d'id
                            - # filtre (ex: "#human")

            *volumeDuSon = (min) 0 ~ 1 (max)


        Exemple :
            # Initialiser une liste de lecture
            lirepiste = PlayMethode(listeDeSons)


            # Passer à la piste suivante selon la méthode: lecture de la liste dans l'ordre
            lirepiste.nextList()

            # Passer à la piste suivante selon la méthode: lecture de la liste dans le désordre
            lirepiste.nextShuf()

            # Passer à la piste suivante selon la méthode: piste choisi aléatoirement dans la liste
            lirepiste.nextRand()


            # Commande: lire la piste choisie selon la méthode
            lirepiste.soundPlay(listeUserId, volumeDuSon)


            # Fonction: obtenir la dernière méthode enregistré (order, shuffle, random)
            lirepiste.getMode()

            # Fonction: obtenir la liste des pistes sur laquelle le module travail
            lirepiste.getList()

            # Fonction: obtenir la piste choisie selon la méthode
            lirepiste.getPath()
    """


    def __init__(self,listeDeSons):
        """
            Initialisation des champs (listes et index)
        """


        # Obtention de la liste de lecture
        self.__initList = listeDeSons

        # Attribution de l'index par défault
        self.__indeList = -1

        # Création d'une liste sur laquelle le module va travailler
        self.__workList = []

        # Permet d'enregister la dernière méthode utilisé (par default = 'None')
        self.__modeCast = None


    def nextList(self):
        """
            fonction public: jouer la liste dans l'ordre
        """


        # Enregistrement de la méthode utilisé
        self.__modeCast = "order"

        # Si l'index est 'par défault' ou si celui-ci atteint la fin de la liste
        if self.__indeList == len(self.__workList) - 1:

            # Initialisation de la liste dans l'ordre
            self.__workList = self.__initList

            # Initialisation de l'index
            self.__indeList = 0

        # Sinon
        else:

            # Incrémentation de celui-ci dans le cas contraire.
            self.__indeList += 1


    def nextShuf(self):
        """
            fonction public: jouer les pistes de la liste dans le désordre
        """


        # Enregistrement de la méthode utilisé
        self.__modeCast = "shuffle"

        # Si l'index est 'par défault' ou si celui-ci atteint la fin de la liste
        if self.__indeList == len(self.__workList) - 1:

            # Initialisation de la liste dans l'ordre
            self.__workList = self.__initList

            # Mélange des pistes de la liste
            random.shuffle(self.__workList)

            # Initialisation de l'index
            self.__indeList = 0

        # Sinon
        else:

            # Incrémentation de celui-ci dans le cas contraire.
            self.__indeList += 1


    def nextRand(self):
        """
            fonction public: jouer un son choisit aléatoirement dans la liste
        """


        # Enregistrement de la méthode utilisé
        self.__modeCast = "random"

        # Si la liste de travail est 'par default'
        if not self.__workList:

            # Obtention de la liste de lecture
            self.__workList = self.__initList

        # Puis, atribution de l'index de manière aléatoire
        self.__indeList = random.randint(0, len(self.__workList) - 1)


    def soundPlay(self, identifiant, volume):
        """
            Fonction public: commande de lecture du son selectionné
        """


        # Lecture du son au joueur sélectionné
        es.playsound(identifiant, self.__workList[self.__indeList], volume)


    def getMode(self):
        """
            Fonction public: obtenir la dernière méthode utilisé (order, shuffle & random)
        """


        # Renvoie la piste sélectionné
        return self.__modeCast


    def getList(self):
        """
            Fonction public: obtenir la liste de lecture sue laquelle le module travail
        """


        # Renvoie la liste sur laquelle le module travail
        return self.__workList[:]


    def getPath(self):
        """
            Fonction public: obtenir le repertoire du sons selectionné
        """


        # Renvoie la piste sélectionné
        return self.__workList[self.__indeList]

#=====================================================================================================#
